import _slicedToArray from '@babel/runtime/helpers/esm/slicedToArray';
import { useState, useEffect } from 'react';

var useActive = function useActive() {
  var _React$useState = useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isActive = _React$useState2[0],
      setActive = _React$useState2[1];

  var bind = {
    onMouseDown: function onMouseDown(e) {
      return setActive(true);
    },
    onMouseUp: function onMouseUp(e) {
      return setActive(false);
    }
  };
  return [isActive, bind];
};

var useFocus = function useFocus() {
  var _React$useState = useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isFocused = _React$useState2[0],
      setFocused = _React$useState2[1];

  var bind = {
    onFocus: function onFocus(e) {
      return setFocused(true);
    },
    onBlur: function onBlur(e) {
      return setFocused(false);
    }
  };
  return [isFocused, bind];
};

var useHover = function useHover() {
  var _React$useState = useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isHovered = _React$useState2[0],
      setHovered = _React$useState2[1];

  var bind = {
    onMouseEnter: function onMouseEnter(e) {
      return setHovered(true);
    },
    onMouseLeave: function onMouseLeave(e) {
      return setHovered(false);
    }
  };
  return [isHovered, bind];
};

var useTouch = function useTouch() {
  var _React$useState = useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isTouched = _React$useState2[0],
      setTouched = _React$useState2[1];

  var bind = {
    onTouchStart: function onTouchStart(e) {
      return setTouched(true);
    },
    onTouchEnd: function onTouchEnd(e) {
      return setTouched(false);
    }
  };
  return [isTouched, bind];
};

var useClickOutside = function useClickOutside(ref, onClickOutside) {
  var _React$useState = useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isActive = _React$useState2[0],
      setActive = _React$useState2[1];

  var mousedown = function mousedown(e) {
    var current = ref.current;

    if (current !== null && !current.contains(e.target)) {
      setActive(true);
      onClickOutside(e);
    }
  };

  var mouseup = function mouseup(e) {
    var current = ref.current;

    if (current !== null && !current.contains(e.target)) {
      setActive(false);
    }
  };

  useEffect(function () {
    document.addEventListener('mousedown', mousedown);
    document.addEventListener('mouseup', mouseup);
    return function () {
      document.removeEventListener('mousedown', mousedown);
      document.removeEventListener('mouseup', mouseup);
    };
  }, []);
  return [isActive];
};

var useMousePosition = function useMousePosition() {
  var _React$useState = useState(0),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      x = _React$useState2[0],
      setX = _React$useState2[1];

  var _React$useState3 = useState(0),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      y = _React$useState4[0],
      setY = _React$useState4[1];

  var bind = {
    onMouseMove: function onMouseMove(_ref) {
      var _ref$nativeEvent = _ref.nativeEvent,
          offsetX = _ref$nativeEvent.offsetX,
          offsetY = _ref$nativeEvent.offsetY;
      setX(offsetX);
      setY(offsetY);
    }
  };
  return [x, y, bind];
};

export { useActive, useFocus, useHover, useTouch, useClickOutside, useMousePosition };
